==> kubernetes-model-1.0.31-sources.jar: io/fabric8/openshift/api/model/BuildConfigStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class BuildConfigStatusFluentImpl<T extends BuildConfigStatusFluent<T>> extends BaseFluent<T> implements BuildConfigStatusFluent<T>{

     Integer lastVersion;     Map<String, Object> additionalProperties = new HashMap();

    public Integer getLastVersion(){
    return this.lastVersion;
    }
    public T withLastVersion( Integer lastVersion){
    this.lastVersion=lastVersion; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
BuildConfigStatusFluentImpl that = (BuildConfigStatusFluentImpl) o;
if (lastVersion != null ? !lastVersion.equals(that.lastVersion) :that.lastVersion != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.33-sources.jar: io/fabric8/openshift/api/model/BuildConfigStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class BuildConfigStatusFluentImpl<T extends BuildConfigStatusFluent<T>> extends BaseFluent<T> implements BuildConfigStatusFluent<T>{

     Integer lastVersion;     Map<String, Object> additionalProperties = new HashMap();
public BuildConfigStatusFluentImpl(){
    
}
public BuildConfigStatusFluentImpl( BuildConfigStatus instance ){
    this.withLastVersion(instance.getLastVersion()); 
}

    public Integer getLastVersion(){
    return this.lastVersion;
    }
    public T withLastVersion( Integer lastVersion){
    this.lastVersion=lastVersion; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
BuildConfigStatusFluentImpl that = (BuildConfigStatusFluentImpl) o;
if (lastVersion != null ? !lastVersion.equals(that.lastVersion) :that.lastVersion != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
